@@ -1,10 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) notes:
- *  An Idea and Atari version: LK Avalon, Janusz Pelc, 1989
- *                 Linux Code: Arkadiusz Lipiec, 2002-2009
- *                                 <arkadiusz.lipiec@gmail.com>
- *                             Thunor 2007-2009
- *                                 <thunorsif@hotmail.com>
+ *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -618,8 +613,8 @@ int ROB_FreeAllChildObjects(ROB_Object *pob, int free_pob) {
 /* This frees all descendant objects of an ancestor if any exist. This can be
    viewed as a way of freeing a group of objects that share a common ancestor */
 
-/* On entry: pob is a pointer to a parent object
-			 free_pob = TRUE to free the parent object also */
+/* On entry: ancestor is a pointer to an ancestor object
+			 free_ancestor = TRUE to free the ancestor object also */
 /*  On exit: returns ROB_ERROR_NONE on success else
 			 any one of the error codes in ROB_engine.h */
 
@@ -695,8 +690,13 @@ int ROB_FreeObject(ROB_Object *rob_object, int free_images_only) {
 					}
 				}
 				/* Free the SDL surface but not rob_sprites or GNU Robbo images */
-				if (img_surface != rob_sprites &&
-					img_surface != icons && img_surface != ciphers && img_surface != alpha && img_surface != icon) {
+				if (img_surface != rob_sprites && 
+					img_surface != wm_icon && 
+					img_surface != icons && 
+					img_surface != ciphers && 
+					img_surface != alpha && 
+					img_surface != bgrnd && 
+					img_surface != k_icons) {
 					SDL_FreeSurface(img_surface);
 				}
 			}
@@ -733,13 +733,13 @@ int ROB_FreeObject(ROB_Object *rob_object, int free_images_only) {
 			 any one of the error codes in ROB_engine.h */
 	
 int ROB_RenderObjects(void) {
-	int count, retval = ROB_ERROR_NONE, found;
+	int cx, cy, ix = 0, iy = 0, iw = 0, ih = 0, alpha, alpha_over, alpha_press, finalalpha = 0;
 	int overeventfound, presseventfound, use_rleaccel = 0;
-	int cx, cy, ix, iy, iw, ih, alpha, alpha_over, alpha_press, finalalpha;
+	int count, retval = ROB_ERROR_NONE, found;
+	SDL_Surface *img_surface = NULL;
 	SDL_Rect srcrect, dstrect;
-	SDL_Surface *img_surface;
 	SDL_PixelFormat *flags;
-	Uint32 bgcolour;
+	Uint32 bgcolour = 0;
 	
 	/* Iterate through the objects */
 	for (count = 0; count < rob_object_count; count++) {
