@@ -1,10 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) notes:
- *  An Idea and Atari version: LK Avalon, Janusz Pelc, 1989
- *                 Linux Code: Arkadiusz Lipiec, 2002-2009
- *                                 <arkadiusz.lipiec@gmail.com>
- *                             Thunor 2007-2009
- *                                 <thunorsif@hotmail.com>
+ *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -38,7 +33,7 @@
 #define TXT_HELP_PAGE3_ROWS 7
 #define TXT_OPTIONS_PAGE1_ROWS 12
 #define TXT_ENDSCREEN_CONGRATS_ROWS 3
-#define TXT_MAX_COLS 60
+#define TXT_MAX_COLS 100
 
 /* Variables */
 char txt_intro_story[TXT_INTRO_STORY_ROWS * TXT_MAX_COLS];
@@ -120,6 +115,8 @@ char txt_By[TXT_MAX_COLS];
 char txt_Level_Author[TXT_MAX_COLS];
 char txt_endscreen_congrats[TXT_ENDSCREEN_CONGRATS_ROWS * TXT_MAX_COLS];
 
+char txt_Sound[TXT_MAX_COLS];
+char txt_Snd_Vol[TXT_MAX_COLS];
 char txt_Volume[TXT_MAX_COLS];
 char txt_Changes_saved[TXT_MAX_COLS];
 char txt_Default_controls_restored[TXT_MAX_COLS];
