@@ -1,10 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) notes:
- *  An Idea and Atari version: LK Avalon, Janusz Pelc, 1989
- *                 Linux Code: Arkadiusz Lipiec, 2002-2009
- *                                 <arkadiusz.lipiec@gmail.com>
- *                             Thunor 2007-2009
- *                                 <thunorsif@hotmail.com>
+ *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -116,6 +111,7 @@ void show_helpscreen(void);
 void show_optionsscreen(void);
 void show_message_box(int subfunction, MSG_Box *msg_box);
 void show_endscreen(void);
+void show_scoreline (void);
 
 
 
