@@ -1,10 +1,5 @@
 /*  GNU Robbo
- *  Copyright (C) notes:
- *  An Idea and Atari version: LK Avalon, Janusz Pelc, 1989
- *                 Linux Code: Arkadiusz Lipiec, 2002-2009
- *                                 <arkadiusz.lipiec@gmail.com>
- *                             Thunor 2007-2009
- *                                 <thunorsif@hotmail.com>
+ *  Copyright (C) 2002-2009 The GNU Robbo Team (see AUTHORS).
  *
  *  GNU Robbo is free software - you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -49,21 +44,9 @@ SDL_Surface *icons;
 SDL_Surface *ciphers;
 SDL_Surface *alpha;
 SDL_Surface *icon;
+SDL_Surface *bgrnd;
 TTF_Font *font;
 
-#ifdef HILDON
-enum ARROWS {
-  ARROW_UP,
-  ARROW_DOWN,
-  ARROW_LEFT,
-  ARROW_RIGHT,
-
-  ARROW_SIZE
-};
-
-extern SDL_Surface * arrows[ARROW_SIZE];
-#endif
-
 SDL_Rect robbo_images_srcrect[8];
 SDL_Rect score_images_srcrect[10];
 SDL_Rect score_screw_srcrect;
@@ -71,38 +54,37 @@ SDL_Rect score_key_srcrect;
 SDL_Rect score_bullet_srcrect;
 SDL_Rect score_level_srcrect;
 
-struct skin {
-	char foldername[100];	/* e.g. tronic */
-	char name[60];			/* e.g. Tronic */
-	char author[60];
-	char about[3][60];		/* Up to 3 lines of text */
-	Uint32 background_colour;
-	Uint32 version_text_colour;
-	Uint32 general_text_colour;
-	Uint32 menu_text_colour;
-	Uint32 menu_selected_text_colour;
-	Uint32 menu_selected_limit_text_colour;
-	Uint32 menu_greyed_text_colour;
-	Uint32 default_controls_text_colour;
-	Uint32 credits_text_colour;
-	Uint32 help_tile_colour;
-	Uint32 fade_colour;
-	Uint32 author_text_colour;
+struct skin
+{
+  char foldername[100];		/* e.g. tronic */
+  char name[60];		/* e.g. Tronic */
+  char author[60];
+  char about[3][60];		/* Up to 3 lines of text */
+  char soundskin[60];		/* file name of the sound skin */
+  Uint32 background_colour;
+  Uint32 version_text_colour;
+  Uint32 general_text_colour;
+  Uint32 menu_text_colour;
+  Uint32 menu_selected_text_colour;
+  Uint32 menu_selected_limit_text_colour;
+  Uint32 menu_greyed_text_colour;
+  Uint32 default_controls_text_colour;
+  Uint32 credits_text_colour;
+  Uint32 help_tile_colour;
+  Uint32 fade_colour;
+  Uint32 author_text_colour;
 };
 struct skin skins[MAX_SKINS];
 
-int skin_count;				/* How many skins are in the list */
-int selected_skin;			/* Which skin in the list is currently selected */
+int skin_count;			/* How many skins are in the list */
+int selected_skin;		/* Which skin in the list is currently selected */
 int temp_selected_skin;
 
 /* Function prototypes */
-int find_all_skins(void);
-void read_skinrc_files(void);
-void sort_skins(void);
-int read_skin_level_colour_override(void);
-void load_selected_skin(void);
-SDL_Surface *create_skin_preview(void);
-
-
-
-
+int find_all_skins (void);
+void read_skinrc_files (void);
+void sort_skins (void);
+int read_skin_level_colour_override (void);
+void load_selected_skin (void);
+SDL_Surface *create_skin_preview (void);
+void load_TTF_font (void);
